FontEntity class

Constructors

FontEntity({String? fontName, double? size, int? weight, int? style, int? decoration, RgbEntity? color})

Properties

color → RgbEntity?
final
decoration → int?
final
fontName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double?
final
style → int?
final
weight → int?
final

Methods

copyWith({String? fontName, double? size, int? weight, int? style, int? decoration, RgbEntity? color}) → FontEntity
enrichedDocument(Map<String, Object?> theDocument) → Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchAppId({required String newAppId}) → FontEntity
override
toDocument() → Map<String, Object?>
override
toJsonString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonString(String json, {Map<String, String>? newDocumentIds}) → FontEntity?
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → FontEntity?